Parallel calculations — ASE documentation

### Navigation

- index
- modules |
- Documentation for modules in ASE »

# Parallel calculations

`ase.parallel.` `paropen`(name, mode='r')

  MPI-safe version of open function.

  In read mode, the file is opened on all nodes. In write and append mode, the file is opened on the master only, and /dev/null is opened on all other nodes.

`ase.parallel.` `parprint`(*args, **kwargs)

  MPI-safe print - prints only from master.

### Navigation

- index
- modules |
- Documentation for modules in ASE »